@@ -119,6 +119,11 @@ class Recipe:
             zope_conf_additional = options.get('zope-conf-additional', '')
         
             base_dir = self.buildout['buildout']['directory']
+
+            socket_name = options.get('socket-name', '%s/var/zeo.zdsock' % base_dir)
+            socket_dir = os.path.dirname(socket_name)
+            if not os.path.exists(socket_dir):
+                os.makedirs(socket_dir)
         
             z_log_name = options.get('zeo-log', os.path.sep.join(('var', 'log', self.name + '.log',)))
             z_log = os.path.join(base_dir, z_log_name)
@@ -134,6 +139,7 @@ class Recipe:
             
             zope_conf = zope_conf_template % dict(instance_home = instance_home,
                                                   effective_user = effective_user,
+                                                  socket_name = socket_name,
                                                   z_log = z_log,
                                                   file_storage = file_storage,
                                                   zeo_address = zeo_address,
@@ -236,7 +242,7 @@ zope_conf_template="""\
 
 <runner>
   program $INSTANCE/bin/runzeo
-  socket-name $INSTANCE/etc/zeo.zdsock
+  socket-name %(socket_name)s
   daemon true
   forever false
   backoff-limit 10
@@ -244,8 +250,6 @@ zope_conf_template="""\
   directory $INSTANCE
   default-to-interactive true
   %(effective_user)s
-  #python /usr/bin/python2.4
-  #zdrun /opt/Zope-2.9.0/lib/python/zdaemon/zdrun.py
 
   # This logfile should match the one in the zeo.conf file.
   # It is used by zdctl's logtail command, zdrun/zdctl doesn't write it.
